@@ -7,7 +7,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-use version; our $VERSION = version->declare('v0.1.1');
+use version; our $VERSION = version->declare('v0.1.2');
 
 =head1 NAME
 
@@ -183,10 +183,14 @@ sub rotate {
           next;
       }
 
-      my $ext = $index + 1;
-      my $new = $index
-          ? $file =~ s/[.]${index}$/.${ext}/r
-          : $file . '.' . $ext;
+      my $next = $index + 1;
+      my $new = $file->stringify;
+
+      if ($index) {
+          $new =~ s/[.]${index}$/.${next}/;
+      } else {
+          $new .= '.' . $next;
+      }
 
       $file->move($new);
   }
